@@ -21,6 +21,15 @@ class NamedSeries(Series):
         super().__init__(*args, **kwargs)
         self.contents = contents
 
+    def rename_contents(  # dead: disable
+        self: NamedSeries, contents: Optional[Hashable] = None,
+    ) -> NamedSeries:
+        """Rename the contents of the Series."""
+
+        out = self.copy()
+        out.contents = contents
+        return out
+
     _metadata = ["contents"]  # dead: disable
 
     @property
@@ -41,6 +50,15 @@ class NamedDataFrame(DataFrame):
         super().__init__(*args, **kwargs)
         self.contents = contents
 
+    def rename_contents(  # dead: disable
+        self: NamedDataFrame, contents: Optional[Hashable] = None,
+    ) -> NamedDataFrame:
+        """Rename the contents of the DataFrame."""
+
+        out = self.copy()
+        out.contents = contents
+        return out
+
     _metadata = ["contents"]  # dead: disable
 
     @property
